@@ -1,6 +1,6 @@
 /* discover.c -- Hardware-querying utility
  *
- * $Progeny: discover.c 4750 2005-01-27 15:27:56Z licquia $
+ * $Progeny$
  *
  * Copyright 2000, 2001, 2002 Progeny Linux Systems, Inc.
  * Copyright 2002 Hewlett-Packard Company
@@ -295,7 +295,13 @@ print_or_unknown(char *s)
 static void
 print_device_list(discover_device_t *device)
 {
-    for (; device; device = discover_device_get_next(device)) {
+    int i = 0;
+    for (i = 0; device; device = discover_device_get_next(device), i++) {
+        if (strcmp(discover_device_get_model_id(device), "default") == 0) {
+            if (discover_device_get_next(device) || i != 0) {
+                continue;
+            }
+        }
         if (do_vendor_id) {
             print_or_unknown(discover_device_get_vendor_id(device));
         }
