@@ -7,7 +7,7 @@
  * storing the XML data during the parsing process.
  */
 
-/* $Progeny: device-xml.c 4753 2005-01-29 17:15:42Z licquia $
+/* $Progeny$
  *
  * AUTHOR: John R. Daily <jdaily@progeny.com>
  *
@@ -559,7 +559,8 @@ discover_xml_find_device(discover_device_t *xml_devices,
          device;
          device = device->next) {
         if (target_vendor && target_model) {
-            if (strcmp(device->model_id, target_model) == 0
+            if ((strcmp(device->model_id, target_model) == 0 ||
+                 strcmp(device->model_id, "default") == 0)
                 && strcmp(device->vendor_id, target_vendor) == 0) {
                 break;
             }
@@ -569,7 +570,7 @@ discover_xml_find_device(discover_device_t *xml_devices,
             }
         } else {
             /* We only have target_model. */
-            if (strcmp(device->model_id, target_model) == 0) {
+            if ((strcmp(device->model_id, target_model) == 0)) {
                 break;
             }
         }
@@ -629,7 +630,7 @@ discover_xml_get_matching_devices(discover_device_t *xml_devices,
         copy->extra = NULL;
 
         if (last) {
-            last->extra = copy;
+            last->next = copy;
         } else {
             head_device = copy;
         }
