@@ -8,7 +8,7 @@
  * Discover API.
  */
 
-/* $Progeny: device.c 4750 2005-01-27 15:27:56Z licquia $
+/* $Progeny$
  *
  * Copyright 2001, 2002 Progeny Linux Systems, Inc.
  * Copyright 2002 Hewlett-Packard Company
@@ -99,12 +99,16 @@ discover_device_find(char *discover_class, discover_error_t *status)
                 new_device->next = NULL;
 
                 if (last) {
+                    for (; last->next; last = last->next)
+                        ;
                     last->next = new_device;
                     last = new_device;
                 } else {
                     result = last = new_device;
                 }
             }
+            else {
+            }
         }
 
         if (status->code != 0) {
