@@ -1,4 +1,4 @@
-/* $Progeny: pci.c 4762 2005-01-30 07:03:56Z licquia $ */
+/* $Progeny$ */
 
 /* pci.c - Scan the PCI bus
  *
@@ -160,7 +160,7 @@ _discover_get_pci_raw_sys(void)
     FILE *f;
     DIR *pciDir;
     struct dirent *pci_device_entry;
-    int len;
+    unsigned int len;
     char *device_dir, *line, *class, *vendor, *model, *p;
     char **device_dir_list = NULL;
     size_t device_dir_list_len, device_dir_index, device_dir_index2;
